@@ -164,8 +164,28 @@ nm_bt_setup_device_paired_cb(NmBtUtils *bt_utils, gboolean paired, gpointer user
 											 "Could not connect to PC");
             return;
 		}
+   
+        /* Enable dhcpd if checkbox active */
+        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->dhcpd_entry))) {
+            
+            /* Make sure that the bnep interface is up before start dhcp */
+            int i;
+            for(i = 0; i < 3; ++i) {
+                if (nm_bt_utils_has_network_connection(priv->bt_utils) == FALSE) {
+                    g_debug("[%s] - sleep", __FUNCTION__);
+                    sleep(1);
+                    
+                }
+                else {
+                    break;
+                }
+            }
+            g_debug("[%s] - out of sleep", __FUNCTION__);
+            
+            nm_bt_setup_enable_dhcpd(user_data, settings, TRUE);
+        }
 
-		hildon_banner_show_information(NULL, NULL, "Bluetooth network enabled");
+		hildon_banner_show_information(NULL, NULL, "Bluetooth network enabled");		
 	}
 	else {
 
@@ -500,6 +520,7 @@ nm_bt_setup_apply_changes (NmConnWidget *self)
 												 _("Could not pair PC"));
 				return FALSE;
 			}
+			
         }
 #endif
     } else {
