@@ -56,6 +56,7 @@ struct _NmSbrshSetupPrivate
     GtkWidget *allowed_ips_button;
     
     gchar *env;
+    gboolean is_installed;
 };
 
 #define NM_SBRSH_SETUP_GET_PRIVATE(o) \
@@ -71,6 +72,7 @@ static void nm_sbrsh_setup_create_widget (NmSbrshSetup *);
 static void nm_sbrsh_setup_enable_cb (GtkToggleButton *, gpointer);
 static void nm_sbrsh_setup_enable_options (NmSbrshSetup *, gboolean);
 static void nm_sbrsh_setup_manage_allowed_ips(gpointer , gpointer);
+static gboolean nm_sbrsh_setup_is_installed (NmSbrshSetup *);
     
 G_DEFINE_TYPE (NmSbrshSetup, nm_sbrsh_setup, NM_CONN_WIDGET_TYPE)
 
@@ -141,6 +143,16 @@ nm_sbrsh_setup_is_enabled (NmSbrshSetup *self)
     return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(priv->checkbutton));
 }
 
+static gboolean
+nm_sbrsh_setup_is_installed (NmSbrshSetup *self)
+{
+    gint ret = system("sudo /usr/sbin/nm-sbrsh-setup isinstalled");
+    
+    g_debug("[%s] - Sbrsh is installed: %d", __FUNCTION__, ret);
+    
+    return ret;
+}
+
 static void
 nm_sbrsh_setup_create_widget (NmSbrshSetup *self)
 {
@@ -149,6 +161,17 @@ nm_sbrsh_setup_create_widget (NmSbrshSetup *self)
 
     priv = NM_SBRSH_SETUP_GET_PRIVATE (self);
 
+    priv->is_installed = nm_sbrsh_setup_is_installed(self);
+
+    if (!priv->is_installed) {
+        GtkWidget *not_installed = gtk_label_new(_("SBRSH package is not installed"));
+#ifdef DIABLO
+        gtk_widget_set_size_request(not_installed, 359, -1);
+#endif
+        gtk_container_add(GTK_CONTAINER (self), not_installed);
+        return;      
+    }
+
     table = gtk_table_new (6, 2, TRUE);
 
     priv->checkbutton = gtk_check_button_new_with_label (_("enable"));
@@ -290,6 +313,10 @@ nm_sbrsh_setup_apply_changes (NmConnWidget *self)
     
     NmSbrshSetupPrivate *priv;
     priv = NM_SBRSH_SETUP_GET_PRIVATE (sbrshsetup);
+
+    if (!priv->is_installed) {
+        return TRUE;
+    }
     
     nm_sbrsh_setup_save_changes(sbrshsetup);
     
@@ -300,7 +327,7 @@ nm_sbrsh_setup_apply_changes (NmConnWidget *self)
         gsize length = 0;
         gchar **list = nm_file_dialog_get_list(NM_FILE_DIALOG(dialog), &length);
         
-        gchar *concat_list = "";
+        gchar *concat_list = g_strdup("");
         int i;
         for (i = 0; i < length; i++) {
             concat_list = g_strconcat(concat_list, " ", list[i], NULL);
@@ -374,6 +401,10 @@ nm_sbrsh_setup_save_changes (NmSbrshSetup *self)
 {
     NmSbrshSetupPrivate *priv = NM_SBRSH_SETUP_GET_PRIVATE (self);
 
+    if (!priv->is_installed) {
+        return;
+    }
+
     NmSettings *settings = nm_settings_new();
   
     nm_settings_set_boolean (settings, priv->env, NM_SBRSH_SETTINGS_GROUP,
@@ -423,6 +454,10 @@ void
 nm_sbrsh_setup_fill_widget(NmSbrshSetup *self)
 {
     NmSbrshSetupPrivate *priv = NM_SBRSH_SETUP_GET_PRIVATE (self);
+
+    if (!priv->is_installed) {
+        return;
+    }
     
     if (strcmp(priv->env, nm_environment_manager_get_active())) {
 /*        g_debug("[%s] - %s is not the active environment", __FUNCTION__, priv->env);*/
