@@ -48,6 +48,7 @@ struct _NmVncSetupPrivate
     GtkWidget *loop_checkbox;
     
     gchar *env;
+    gboolean is_installed;
 };
 
 #define NM_VNC_SETUP_GET_PRIVATE(o) \
@@ -62,6 +63,7 @@ static void nm_vnc_setup_defaults (NmVncSetup *, gboolean);
 static void nm_vnc_setup_create_widget (NmVncSetup *);
 static void nm_vnc_setup_enable_cb (GtkToggleButton *, gpointer);
 static void nm_vnc_setup_enable_options (NmVncSetup *, gboolean);
+static gboolean nm_vnc_setup_is_installed (NmVncSetup *);
     
 G_DEFINE_TYPE (NmVncSetup, nm_vnc_setup, NM_CONN_WIDGET_TYPE)
 
@@ -132,6 +134,16 @@ nm_vnc_setup_is_enabled (NmVncSetup *self)
     return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(priv->checkbutton));
 }
 
+static gboolean
+nm_vnc_setup_is_installed (NmVncSetup *self)
+{
+    gint ret = system("sudo /usr/sbin/nm-vnc-setup isinstalled");
+    
+    g_debug("[%s] - Vnc is installed: %d", __FUNCTION__, ret);
+    
+    return ret;
+}
+
 static void
 nm_vnc_setup_create_widget (NmVncSetup *self)
 {
@@ -140,6 +152,17 @@ nm_vnc_setup_create_widget (NmVncSetup *self)
 
     priv = NM_VNC_SETUP_GET_PRIVATE (self);
 
+    priv->is_installed = nm_vnc_setup_is_installed(self);
+
+    if (!priv->is_installed) {
+        GtkWidget *not_installed = gtk_label_new(_("VNC package is not installed"));
+#ifdef DIABLO
+        gtk_widget_set_size_request(not_installed, 359, -1);
+#endif
+        gtk_container_add(GTK_CONTAINER (self), not_installed);
+        return;      
+    }
+
     table = gtk_table_new (5, 2, TRUE);
 
     priv->checkbutton = gtk_check_button_new_with_label (_("enable"));
@@ -242,7 +265,11 @@ nm_vnc_setup_apply_changes (NmConnWidget *self)
     
     NmVncSetupPrivate *priv;
     priv = NM_VNC_SETUP_GET_PRIVATE (vncsetup);
-    
+
+    if (!priv->is_installed) {
+        return TRUE;
+    }
+        
     nm_vnc_setup_save_changes(vncsetup);
     
     if ( nm_vnc_setup_is_enabled(vncsetup) ) {
@@ -298,6 +325,10 @@ nm_vnc_setup_save_changes (NmVncSetup *self)
 {
     NmVncSetupPrivate *priv = NM_VNC_SETUP_GET_PRIVATE (self);
 
+    if (!priv->is_installed) {
+        return;
+    }
+
     NmSettings *settings = nm_settings_new();
   
     nm_settings_set_boolean (settings, priv->env, NM_VNC_SETTINGS_GROUP,
@@ -340,6 +371,10 @@ void
 nm_vnc_setup_fill_widget(NmVncSetup *self)
 {
     NmVncSetupPrivate *priv = NM_VNC_SETUP_GET_PRIVATE (self);
+
+    if (!priv->is_installed) {
+        return;
+    }
     
     if (strcmp(priv->env, nm_environment_manager_get_active())) {
 /*        g_debug("[%s] - %s is not the active environment", __FUNCTION__, priv->env);*/
