@@ -44,6 +44,7 @@ static void nm_wlan_setup_create_widget (NmWlanSetup *);
 static void nm_wlan_setup_enable_cb (GtkToggleButton *, gpointer);
 static void nm_wlan_setup_enable_options (NmWlanSetup *, gboolean);
 static int nm_wlan_setup_enable_dhcpd(NmWlanSetup *, gboolean);
+static gboolean nm_wlan_setup_wep_changed_cb(GtkWidget *, GdkEventFocus *, gpointer);
 
 typedef struct _NmWlanSetupPrivate NmWlanSetupPrivate;
 
@@ -68,6 +69,7 @@ struct _NmWlanSetupPrivate
     NmWlanUtils *wlan_utils;
     
     gchar *env;
+    gboolean wep_valid;
 };
 
 #define NM_WLAN_SETUP_GET_PRIVATE(o) \
@@ -193,6 +195,9 @@ nm_wlan_setup_create_widget(NmWlanSetup *self)
     priv->wep_label = gtk_label_new(_("WEP Key: "));
     gtk_misc_set_alignment(GTK_MISC(priv->wep_label), 1, 0.5);
     priv->wep_entry = gtk_entry_new();
+    g_signal_connect (priv->wep_entry, "focus-out-event", G_CALLBACK(nm_wlan_setup_wep_changed_cb),
+                      self);
+    priv->wep_valid = TRUE;
 
     gtk_table_attach_defaults(GTK_TABLE(table), priv->checkbutton, 0, 1, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE (table), priv->dhcpd_label, 0, 1, 1, 2);
@@ -371,7 +376,7 @@ nm_wlan_setup_apply_changes (NmConnWidget *self)
                 gconf_client_set_string (gcClient, NM_GCONF_KEY_WLAN_WEPKEY, value , NULL);
             }
             else {
-                hildon_banner_show_information (NULL, NULL, _("The WEP key needs to have 5, 10 or 13 caracters\nIgnoring key"));
+                hildon_banner_show_information (NULL, NULL, _("The WEP key needs to have 5, 10 or 13 characters\nIgnoring key"));
             }
         }
 
@@ -536,3 +541,39 @@ nm_wlan_setup_fill_widget(NmWlanSetup *self)
     }
 }
 
+static gboolean 
+nm_wlan_setup_wep_changed_cb(GtkWidget *widget, GdkEventFocus *focus, gpointer self)
+{    
+    g_debug("[%s] - called", __FUNCTION__);
+    
+    NmWlanSetupPrivate *priv;
+    priv = NM_WLAN_SETUP_GET_PRIVATE (self);    
+    
+    gchar *wep = gtk_entry_get_text (GTK_ENTRY (priv->wep_entry));
+    
+
+    g_debug("[%s] - size: %d", __FUNCTION__, strlen(wep));
+    if (strlen(wep) != 0 && strlen(wep) != 5 && strlen(wep) != 10 && strlen(wep) != 13) {
+        g_debug("[%s] - Wep size incorrect", __FUNCTION__);
+        hildon_banner_show_information (NULL, NULL, _("The WEP key needs to have 5, 10 or 13 characters"));
+        priv->wep_valid = FALSE;
+    }
+    else {
+        priv->wep_valid = TRUE;
+    }
+
+    return FALSE;
+}
+
+gboolean 
+nm_wlan_setup_is_valid(NmWlanSetup *self)
+{
+    NmWlanSetupPrivate *priv = NM_WLAN_SETUP_GET_PRIVATE (self);
+    if (priv->wep_valid == FALSE) {
+        hildon_banner_show_information (NULL, NULL, _("The WEP key needs to have 5, 10 or 13 characters"));
+        return FALSE;
+    }
+    
+    return TRUE;
+}
+
